@@ -2,7 +2,12 @@ import json
 import re
 from sly import Lexer
 
-
+"""
+Unfortunately we can't inherit from base SQLLexer, because the order of rules is important.
+If we do, like in MySQL lexer, the new rules like `DATASOURCE = r'\bDATASOURCE\b'` are added to the end of the rule list.
+Then, for an input `DATASOURCE`, the last matched regexp is `STRING`, and the token is incorrectly classified 
+as a string.
+"""
 class MindsDBLexer(Lexer):
     reflags = re.IGNORECASE
     ignore = ' \t\n\r'
@@ -103,7 +108,7 @@ class MindsDBLexer(Lexer):
     FULL = r'\bFULL\b'
     VARIABLES = r'\bVARIABLES\b'
     SESSION = r'\bSESSION\b'
-    STATUS = r'\STATUS\b'
+    STATUS = r'\bSTATUS\b'
     GLOBAL = r'\bGLOBAL\b'
     PROCEDURE = r'\bPROCEDURE\b'
     FUNCTION = r'\bFUNCTION\b'
@@ -197,7 +202,7 @@ class MindsDBLexer(Lexer):
         t.value = int(t.value)
         return t
 
-    @_(r'\{[a-zA-Z0-9\"\':,\.\{\}\[\]\s]*\}')
+    @_(r'\{.*\}')
     def JSON(self, t):
         t.value = json.loads(t.value)
         return t
